/* aewm - a minimalistic X11 window manager. ------- vim:sw=4:et
 * Copyright (c) 1998-2001 Decklin Foster <decklin@red-bean.com>
 * Free software! Please see README for details and license.  */

#include "aewm.h"


static void handle_configure_request(XConfigureRequestEvent *e)
{
    XWindowChanges wc;

    wc.x = e->x;
    wc.y = e->y;
    wc.width = e->width;
    wc.height = e->height;
    wc.sibling = e->above;
    wc.stack_mode = e->detail;
    XConfigureWindow(dpy, e->window, e->value_mask, &wc);
}

static void handle_map_request(XMapRequestEvent *e)
{
    Client *c = find_client(e->window);

    if (c) {
        XMapWindow(dpy, c->window);
        set_wm_state(c, NormalState);
	set_focus_on(c->window);
    } else {
        make_new_client(e->window);
    }
}

static void handle_destroy_event(XDestroyWindowEvent *e)
{
    Client *c = find_client(e->window);

    if (c) remove_client(c);
}


void do_event_loop(void)
{
    XEvent ev;

    for (;;) {
        XNextEvent(dpy, &ev);
#ifdef DEBUG
	show_event(ev);
#endif
        switch (ev.type) {
            case ConfigureRequest:
                handle_configure_request(&ev.xconfigurerequest); break;
            case MapRequest:
                handle_map_request(&ev.xmaprequest); break;
            case DestroyNotify:
                handle_destroy_event(&ev.xdestroywindow); break;
        }
    }
}
